==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/SkusNestedResourceTypeSecondArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin

import com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecondArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.inputs.SkuResourcePropertiesArgs
import com.pulumi.azurenative.providerhub.kotlin.inputs.SkuResourcePropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * Azure REST API version: 2021-09-01-preview. Prior API version in Azure Native 1.x: 2020-11-20.
 * ## Example Usage
 * ### Skus_CreateOrUpdateNestedResourceTypeSecond
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var skusNestedResourceTypeSecond = new AzureNative.ProviderHub.SkusNestedResourceTypeSecond("skusNestedResourceTypeSecond", new()
 *     {
 *         NestedResourceTypeFirst = "nestedResourceTypeFirst",
 *         NestedResourceTypeSecond = "nestedResourceTypeSecond",
 *         Properties = new AzureNative.ProviderHub.Inputs.SkuResourcePropertiesArgs
 *         {
 *             SkuSettings = new[]
 *             {
 *                 new AzureNative.ProviderHub.Inputs.SkuSettingArgs
 *                 {
 *                     Kind = "Standard",
 *                     Name = "freeSku",
 *                     Tier = "Tier1",
 *                 },
 *                 new AzureNative.ProviderHub.Inputs.SkuSettingArgs
 *                 {
 *                     Costs = new[]
 *                     {
 *                         new AzureNative.ProviderHub.Inputs.SkuCostArgs
 *                         {
 *                             MeterId = "xxx",
 *                         },
 *                     },
 *                     Kind = "Premium",
 *                     Name = "premiumSku",
 *                     Tier = "Tier2",
 *                 },
 *             },
 *         },
 *         ProviderNamespace = "Microsoft.Contoso",
 *         ResourceType = "testResourceType",
 *         Sku = "testSku",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/providerhub/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * pulumi.Run(func(ctx *pulumi.Context) error {
 * _, err := providerhub.NewSkusNestedResourceTypeSecond(ctx, "skusNestedResourceTypeSecond", &providerhub.SkusNestedResourceTypeSecondArgs{
 * NestedResourceTypeFirst: pulumi.String("nestedResourceTypeFirst"),
 * NestedResourceTypeSecond: pulumi.String("nestedResourceTypeSecond"),
 * Properties: providerhub.SkuResourceResponseProperties{
 * SkuSettings: providerhub.SkuSettingArray{
 * &providerhub.SkuSettingArgs{
 * Kind: pulumi.String("Standard"),
 * Name: pulumi.String("freeSku"),
 * Tier: pulumi.String("Tier1"),
 * },
 * interface{}{
 * Costs: providerhub.SkuCostArray{
 * &providerhub.SkuCostArgs{
 * MeterId: pulumi.String("xxx"),
 * },
 * },
 * Kind: pulumi.String("Premium"),
 * Name: pulumi.String("premiumSku"),
 * Tier: pulumi.String("Tier2"),
 * },
 * },
 * },
 * ProviderNamespace: pulumi.String("Microsoft.Contoso"),
 * ResourceType: pulumi.String("testResourceType"),
 * Sku: pulumi.String("testSku"),
 * })
 * if err != nil {
 * return err
 * }
 * return nil
 * })
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecond;
 * import com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecondArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var skusNestedResourceTypeSecond = new SkusNestedResourceTypeSecond("skusNestedResourceTypeSecond", SkusNestedResourceTypeSecondArgs.builder()
 *             .nestedResourceTypeFirst("nestedResourceTypeFirst")
 *             .nestedResourceTypeSecond("nestedResourceTypeSecond")
 *             .properties(Map.of("skuSettings",
 *                 Map.ofEntries(
 *                     Map.entry("kind", "Standard"),
 *                     Map.entry("name", "freeSku"),
 *                     Map.entry("tier", "Tier1")
 *                 ),
 *                 Map.ofEntries(
 *                     Map.entry("costs", Map.of("meterId", "xxx")),
 *                     Map.entry("kind", "Premium"),
 *                     Map.entry("name", "premiumSku"),
 *                     Map.entry("tier", "Tier2")
 *                 )))
 *             .providerNamespace("Microsoft.Contoso")
 *             .resourceType("testResourceType")
 *             .sku("testSku")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:providerhub:SkusNestedResourceTypeSecond Microsoft.Contoso/ /subscriptions/{subscriptionId}/providers/Microsoft.ProviderHub/providerRegistrations/{providerNamespace}/resourcetypeRegistrations/{resourceType}/resourcetypeRegistrations/{nestedResourceTypeFirst}/resourcetypeRegistrations/{nestedResourceTypeSecond}/skus/{sku}
 * ```
 * @property nestedResourceTypeFirst The first child resource type.
 * @property nestedResourceTypeSecond The second child resource type.
 * @property properties
 * @property providerNamespace The name of the resource provider hosted within ProviderHub.
 * @property resourceType The resource type.
 * @property sku The SKU.
 */
public data class SkusNestedResourceTypeSecondArgs(
    public val nestedResourceTypeFirst: Output<String>? = null,
    public val nestedResourceTypeSecond: Output<String>? = null,
    public val properties: Output<SkuResourcePropertiesArgs>? = null,
    public val providerNamespace: Output<String>? = null,
    public val resourceType: Output<String>? = null,
    public val sku: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecondArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecondArgs =
        com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecondArgs.builder()
            .nestedResourceTypeFirst(nestedResourceTypeFirst?.applyValue({ args0 -> args0 }))
            .nestedResourceTypeSecond(nestedResourceTypeSecond?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .providerNamespace(providerNamespace?.applyValue({ args0 -> args0 }))
            .resourceType(resourceType?.applyValue({ args0 -> args0 }))
            .sku(sku?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkusNestedResourceTypeSecondArgs].
 */
@PulumiTagMarker
public class SkusNestedResourceTypeSecondArgsBuilder internal constructor() {
    private var nestedResourceTypeFirst: Output<String>? = null

    private var nestedResourceTypeSecond: Output<String>? = null

    private var properties: Output<SkuResourcePropertiesArgs>? = null

    private var providerNamespace: Output<String>? = null

    private var resourceType: Output<String>? = null

    private var sku: Output<String>? = null

    /**
     * @param value The first child resource type.
     */
    @JvmName("tqmhksswatumulbf")
    public suspend fun nestedResourceTypeFirst(`value`: Output<String>) {
        this.nestedResourceTypeFirst = value
    }

    /**
     * @param value The second child resource type.
     */
    @JvmName("vcwjchymblsdlkqe")
    public suspend fun nestedResourceTypeSecond(`value`: Output<String>) {
        this.nestedResourceTypeSecond = value
    }

    /**
     * @param value
     */
    @JvmName("bagohavdmxkbowbe")
    public suspend fun properties(`value`: Output<SkuResourcePropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The name of the resource provider hosted within ProviderHub.
     */
    @JvmName("wlpuddsxhepdnhnc")
    public suspend fun providerNamespace(`value`: Output<String>) {
        this.providerNamespace = value
    }

    /**
     * @param value The resource type.
     */
    @JvmName("nkbneijyufhrmcob")
    public suspend fun resourceType(`value`: Output<String>) {
        this.resourceType = value
    }

    /**
     * @param value The SKU.
     */
    @JvmName("sxgkvnmnjpryhtnw")
    public suspend fun sku(`value`: Output<String>) {
        this.sku = value
    }

    /**
     * @param value The first child resource type.
     */
    @JvmName("cjbfovbgqrmprbsq")
    public suspend fun nestedResourceTypeFirst(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nestedResourceTypeFirst = mapped
    }

    /**
     * @param value The second child resource type.
     */
    @JvmName("ymlmcjmaswgyerrd")
    public suspend fun nestedResourceTypeSecond(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nestedResourceTypeSecond = mapped
    }

    /**
     * @param value
     */
    @JvmName("lwmcuaulrsurfxqg")
    public suspend fun properties(`value`: SkuResourcePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument
     */
    @JvmName("jfcrqevfaohmftvp")
    public suspend fun properties(argument: suspend SkuResourcePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = SkuResourcePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The name of the resource provider hosted within ProviderHub.
     */
    @JvmName("hkksmswefgymrgqb")
    public suspend fun providerNamespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providerNamespace = mapped
    }

    /**
     * @param value The resource type.
     */
    @JvmName("gtwttfwxsylltxrh")
    public suspend fun resourceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceType = mapped
    }

    /**
     * @param value The SKU.
     */
    @JvmName("wwqpmjjwcxqhseec")
    public suspend fun sku(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    internal fun build(): SkusNestedResourceTypeSecondArgs = SkusNestedResourceTypeSecondArgs(
        nestedResourceTypeFirst = nestedResourceTypeFirst,
        nestedResourceTypeSecond = nestedResourceTypeSecond,
        properties = properties,
        providerNamespace = providerNamespace,
        resourceType = resourceType,
        sku = sku,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/SkusNestedResourceTypeSecondArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin

import com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecondArgs.builder
import com.pulumi.azurenative.providerhub.kotlin.inputs.SkuResourcePropertiesArgs
import com.pulumi.azurenative.providerhub.kotlin.inputs.SkuResourcePropertiesArgsBuilder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * Azure REST API version: 2021-09-01-preview. Prior API version in Azure Native 1.x: 2020-11-20.
 * ## Example Usage
 * ### Skus_CreateOrUpdateNestedResourceTypeSecond
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var skusNestedResourceTypeSecond = new AzureNative.ProviderHub.SkusNestedResourceTypeSecond("skusNestedResourceTypeSecond", new()
 *     {
 *         NestedResourceTypeFirst = "nestedResourceTypeFirst",
 *         NestedResourceTypeSecond = "nestedResourceTypeSecond",
 *         Properties = new AzureNative.ProviderHub.Inputs.SkuResourcePropertiesArgs
 *         {
 *             SkuSettings = new[]
 *             {
 *                 new AzureNative.ProviderHub.Inputs.SkuSettingArgs
 *                 {
 *                     Kind = "Standard",
 *                     Name = "freeSku",
 *                     Tier = "Tier1",
 *                 },
 *                 new AzureNative.ProviderHub.Inputs.SkuSettingArgs
 *                 {
 *                     Costs = new[]
 *                     {
 *                         new AzureNative.ProviderHub.Inputs.SkuCostArgs
 *                         {
 *                             MeterId = "xxx",
 *                         },
 *                     },
 *                     Kind = "Premium",
 *                     Name = "premiumSku",
 *                     Tier = "Tier2",
 *                 },
 *             },
 *         },
 *         ProviderNamespace = "Microsoft.Contoso",
 *         ResourceType = "testResourceType",
 *         Sku = "testSku",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/providerhub/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * pulumi.Run(func(ctx *pulumi.Context) error {
 * _, err := providerhub.NewSkusNestedResourceTypeSecond(ctx, "skusNestedResourceTypeSecond", &providerhub.SkusNestedResourceTypeSecondArgs{
 * NestedResourceTypeFirst: pulumi.String("nestedResourceTypeFirst"),
 * NestedResourceTypeSecond: pulumi.String("nestedResourceTypeSecond"),
 * Properties: providerhub.SkuResourceResponseProperties{
 * SkuSettings: providerhub.SkuSettingArray{
 * &providerhub.SkuSettingArgs{
 * Kind: pulumi.String("Standard"),
 * Name: pulumi.String("freeSku"),
 * Tier: pulumi.String("Tier1"),
 * },
 * interface{}{
 * Costs: providerhub.SkuCostArray{
 * &providerhub.SkuCostArgs{
 * MeterId: pulumi.String("xxx"),
 * },
 * },
 * Kind: pulumi.String("Premium"),
 * Name: pulumi.String("premiumSku"),
 * Tier: pulumi.String("Tier2"),
 * },
 * },
 * },
 * ProviderNamespace: pulumi.String("Microsoft.Contoso"),
 * ResourceType: pulumi.String("testResourceType"),
 * Sku: pulumi.String("testSku"),
 * })
 * if err != nil {
 * return err
 * }
 * return nil
 * })
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecond;
 * import com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecondArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var skusNestedResourceTypeSecond = new SkusNestedResourceTypeSecond("skusNestedResourceTypeSecond", SkusNestedResourceTypeSecondArgs.builder()
 *             .nestedResourceTypeFirst("nestedResourceTypeFirst")
 *             .nestedResourceTypeSecond("nestedResourceTypeSecond")
 *             .properties(Map.of("skuSettings",
 *                 Map.ofEntries(
 *                     Map.entry("kind", "Standard"),
 *                     Map.entry("name", "freeSku"),
 *                     Map.entry("tier", "Tier1")
 *                 ),
 *                 Map.ofEntries(
 *                     Map.entry("costs", Map.of("meterId", "xxx")),
 *                     Map.entry("kind", "Premium"),
 *                     Map.entry("name", "premiumSku"),
 *                     Map.entry("tier", "Tier2")
 *                 )))
 *             .providerNamespace("Microsoft.Contoso")
 *             .resourceType("testResourceType")
 *             .sku("testSku")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:providerhub:SkusNestedResourceTypeSecond Microsoft.Contoso/ /subscriptions/{subscriptionId}/providers/Microsoft.ProviderHub/providerRegistrations/{providerNamespace}/resourcetypeRegistrations/{resourceType}/resourcetypeRegistrations/{nestedResourceTypeFirst}/resourcetypeRegistrations/{nestedResourceTypeSecond}/skus/{sku}
 * ```
 * @property nestedResourceTypeFirst The first child resource type.
 * @property nestedResourceTypeSecond The second child resource type.
 * @property properties
 * @property providerNamespace The name of the resource provider hosted within ProviderHub.
 * @property resourceType The resource type.
 * @property sku The SKU.
 */
public data class SkusNestedResourceTypeSecondArgs(
    public val nestedResourceTypeFirst: Output<String>? = null,
    public val nestedResourceTypeSecond: Output<String>? = null,
    public val properties: Output<SkuResourcePropertiesArgs>? = null,
    public val providerNamespace: Output<String>? = null,
    public val resourceType: Output<String>? = null,
    public val sku: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecondArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecondArgs =
        com.pulumi.azurenative.providerhub.SkusNestedResourceTypeSecondArgs.builder()
            .nestedResourceTypeFirst(nestedResourceTypeFirst?.applyValue({ args0 -> args0 }))
            .nestedResourceTypeSecond(nestedResourceTypeSecond?.applyValue({ args0 -> args0 }))
            .properties(properties?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .providerNamespace(providerNamespace?.applyValue({ args0 -> args0 }))
            .resourceType(resourceType?.applyValue({ args0 -> args0 }))
            .sku(sku?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [SkusNestedResourceTypeSecondArgs].
 */
@PulumiTagMarker
public class SkusNestedResourceTypeSecondArgsBuilder internal constructor() {
    private var nestedResourceTypeFirst: Output<String>? = null

    private var nestedResourceTypeSecond: Output<String>? = null

    private var properties: Output<SkuResourcePropertiesArgs>? = null

    private var providerNamespace: Output<String>? = null

    private var resourceType: Output<String>? = null

    private var sku: Output<String>? = null

    /**
     * @param value The first child resource type.
     */
    @JvmName("mblidkbrnittonkb")
    public suspend fun nestedResourceTypeFirst(`value`: Output<String>) {
        this.nestedResourceTypeFirst = value
    }

    /**
     * @param value The second child resource type.
     */
    @JvmName("cgssukcxpsotymqt")
    public suspend fun nestedResourceTypeSecond(`value`: Output<String>) {
        this.nestedResourceTypeSecond = value
    }

    /**
     * @param value
     */
    @JvmName("vvtoqtbllybdbjsv")
    public suspend fun properties(`value`: Output<SkuResourcePropertiesArgs>) {
        this.properties = value
    }

    /**
     * @param value The name of the resource provider hosted within ProviderHub.
     */
    @JvmName("acgbwacdibsjbnds")
    public suspend fun providerNamespace(`value`: Output<String>) {
        this.providerNamespace = value
    }

    /**
     * @param value The resource type.
     */
    @JvmName("txunimeuinfknspc")
    public suspend fun resourceType(`value`: Output<String>) {
        this.resourceType = value
    }

    /**
     * @param value The SKU.
     */
    @JvmName("fdxdhmakgndlwhjk")
    public suspend fun sku(`value`: Output<String>) {
        this.sku = value
    }

    /**
     * @param value The first child resource type.
     */
    @JvmName("xfagxbctxxucgcxy")
    public suspend fun nestedResourceTypeFirst(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nestedResourceTypeFirst = mapped
    }

    /**
     * @param value The second child resource type.
     */
    @JvmName("qqpcsqytrrbgnlsy")
    public suspend fun nestedResourceTypeSecond(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.nestedResourceTypeSecond = mapped
    }

    /**
     * @param value
     */
    @JvmName("qgharpcsyebmsjyn")
    public suspend fun properties(`value`: SkuResourcePropertiesArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.properties = mapped
    }

    /**
     * @param argument
     */
    @JvmName("vidpybhxivvinobk")
    public suspend fun properties(argument: suspend SkuResourcePropertiesArgsBuilder.() -> Unit) {
        val toBeMapped = SkuResourcePropertiesArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.properties = mapped
    }

    /**
     * @param value The name of the resource provider hosted within ProviderHub.
     */
    @JvmName("surrgmbsjkhphctd")
    public suspend fun providerNamespace(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.providerNamespace = mapped
    }

    /**
     * @param value The resource type.
     */
    @JvmName("ldgnkjevqkxogdms")
    public suspend fun resourceType(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceType = mapped
    }

    /**
     * @param value The SKU.
     */
    @JvmName("iuqqwycaqcqvufel")
    public suspend fun sku(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    internal fun build(): SkusNestedResourceTypeSecondArgs = SkusNestedResourceTypeSecondArgs(
        nestedResourceTypeFirst = nestedResourceTypeFirst,
        nestedResourceTypeSecond = nestedResourceTypeSecond,
        properties = properties,
        providerNamespace = providerNamespace,
        resourceType = resourceType,
        sku = sku,
    )
}
